#
# spec file for package ftgl
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libftgl2
%bcond_without ftgl_html
Name:           ftgl
Version:        2.4.0
Release:        1.16
Summary:        Library for Using Arbitrary Fonts in OpenGL Applications
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
# was http://ftgl.wiki.sourceforge.net
URL:            https://github.com/frankheckenbach/ftgl
Source0:        https://github.com/frankheckenbach/ftgl/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch1:         ftgl-pkgconfig.patch
Patch2:         ftgl-fix-no-add-needed.patch
# PATCH-FIX-OPENSUSE: install FTVectoriser.h, required by tulip-5.0; kkaempf@suse.de
Patch3:         install-FTVectoriser.h.patch
%if %{with ftgl_html}
BuildRequires:  doxygen
BuildRequires:  texlive-epstopdf
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  freeglut-devel
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc7-c++
%endif
BuildRequires:  ghostscript
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(x11)

%description
FTGL is a C++ library using Freetype2 to render fonts in OpenGL
applications. FTGL supports bitmaps, pixmaps, texture maps, outlines,
polygon mesh, and extruded polygon rendering modes.

%package -n libftgl2
Summary:        Library for Using Arbitrary Fonts in OpenGL Applications
Group:          System/Libraries

%description -n libftgl2
FTGL is a C++ library using Freetype2 to render fonts in OpenGL
applications. FTGL supports bitmaps, pixmaps, texture maps, outlines,
polygon mesh, and extruded polygon rendering modes.

%package devel
Summary:        Development files for the FTGL OpenGL font managing library
Group:          Development/Libraries/C and C++
Requires:       libftgl2 = %{version}

%description devel
FTGL is a C++ library using Freetype2 to render fonts in OpenGL
applications. FTGL supports bitmaps, pixmaps, texture maps, outlines,
polygon mesh, and extruded polygon rendering modes.

This package provides development files.

%package demo
Summary:        Demos for FTGL OpenGL font managing library
Group:          Development/Tools/Other
Conflicts:      %{name}-devel <= 2.1.2

%description demo
FTGL is a C++ library using Freetype2 to render fonts in OpenGL
applications. FTGL supports bitmaps, pixmaps, texture maps, outlines,
polygon mesh, and extruded polygon rendering modes.

This package provides demo application showing usage of the library.

%prep
%setup -q
%patch1
%patch2
%patch3 -p1

%build
export CC=gcc
export CXX=g++
test -x "$(type -p gcc-7)" && export CC=gcc-7
test -x "$(type -p g++-7)" && export CXX=g++-7
autoreconf -fvi
%configure \
	--disable-static
make %{?_smp_mflags} documentationdir=%{_docdir}/%{name}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags} documentationdir=%{_docdir}/%{name}
mkdir -p %{buildroot}%{_defaultdocdir}/libftgl2
cp -pr AUTHORS BUGS COPYING ChangeLog NEWS README TODO %{buildroot}%{_defaultdocdir}/libftgl2
mkdir -p %{buildroot}%{_bindir}
cd demo
/bin/sh ../libtool --mode=install %{_bindir}/install -c FTGLDemo %{buildroot}%{_bindir}/FTGLDemo
/bin/sh ../libtool --mode=install %{_bindir}/install -c FTGLMFontDemo %{buildroot}%{_bindir}/FTGLMFontDemo
/bin/sh ../libtool --mode=install %{_bindir}/install -c c-demo %{buildroot}%{_bindir}/FTGL-c-demo
/bin/sh ../libtool --mode=install %{_bindir}/install -c simple %{buildroot}%{_bindir}/FTGL-simple-demo
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-demo
cp -pr *.cpp *.c *.h %{buildroot}%{_defaultdocdir}/%{name}-demo
cd ..
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libftgl2 -p /sbin/ldconfig
%postun -n libftgl2 -p /sbin/ldconfig

%files -n libftgl2
%doc %dir %{_defaultdocdir}/libftgl2
%doc %{_defaultdocdir}/libftgl2/[ABCNRT]*
%{_libdir}/*.so.*

%files devel
%doc %dir %{_defaultdocdir}/%{name}
%if %{with ftgl_html}
%doc %{_defaultdocdir}/%{name}/html
%endif
%doc %{_defaultdocdir}/%{name}/*.txt
%{_includedir}/FTGL
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files demo
%doc %dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}-demo
%{_bindir}/FTGLDemo
%{_bindir}/FTGLMFontDemo
%{_bindir}/FTGL-c-demo
%{_bindir}/FTGL-simple-demo

%changelog
* Sat Oct 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4.0
  * New setting LegacyOpenGLState(), see README-LegacyOpenGLState
  * Fix/silence compiler warnings
  version 2.3.1:
  * Updates to debian/ build files
  version 2.3.0:
  * Fix a memory leak
  * FTContour: avoid NaN for angles close to 180 degrees
    (see Debian bug #589601, 5.)
  * FTBufferGlyph: fix garbage with bitmap fonts
    (text is still clipped, that seems to be another problem)
  * FTTextureGlyphImpl: fix garbage with bitmap fonts
    (see Debian bug #589601, 4.)
  * FTPixmapGlyph: fix garbage with bitmap fonts
    (see Debian bug #589601, 2.)
  * FTOutlineGlyphImpl, FTPolygonGlyphImpl: avoid uninizitalized
    vectoriser in case of error (see Debian bug #589601, 1.)
  * Various other bugfixes collected through the years
  version 2.2.0:
  * Stable API. Public headers are now frozen.
  * Fixed several memory corruption and crash bugs - Sam Hocevar
  * Fixed several memory leaks - Sam Hocevar
  * Kerning and glyph performance enhancements - Sean Morrison
  * The library now also exports a pure C interface - Éric Beets
  * Inset/outset contour support for fonts - Éric Beets
  * Fix the FTLayout rendering - Éric Beets
  * Added new FTLayout and FTSimpleLayout support for layout
    managers - Sam Hocevar
  * Fixed the paths in the XCode project - Henry Maddocks
  * Changed the behaviour of some objects so that if there is an
    error their state isn't changed - Henry Maddocks
  * New, fast FTBufferFont texture fonts - Sam Hocevar
  * UTF-8 support - Daniel Remenak
- Switch to maintained fork
- Dropped ftgl-autoreconf.patch (merged upstream)
- Refreshed install-FTVectoriser.h.patch
* Fri Mar  8 2019 olaf@aepfle.de
- Add conditional for html docs, SLE_12 has no epstopdf
* Mon Mar 26 2018 crrodriguez@opensuse.org
- Remove Requires on Mesa-devel, automated pkgconfig()
  Requires are enough in this case.
* Thu Dec  7 2017 kkaempf@suse.com
- adapt install-FTVectoriser.h.patch to install more .h files
  required by tulip-5.1.0
* Wed Jul 12 2017 jengelh@inai.de
- Remove --with-pic which is only for static libs.
- RPM group fix.
- Trim redundant wording from description.
* Wed Jul 12 2017 tchvatal@suse.com
- Trim a bit description and fix group for demo
* Wed Jun 28 2017 kkaempf@suse.com
- add install-FTVectoriser.h.patch
  install FTVectoriser.h, required by tulip-5.0
- fix documentation build
  (add texlive-epstopdf and ghostscript to BuildRequires)
* Tue Apr 14 2015 tiwai@suse.de
- Fix download URL containing percent letters to make "osc service
  localrun download_files" working
* Mon Apr 13 2015 mpluskal@suse.com
- Add baselibs to sources
* Sun Apr 12 2015 mpluskal@suse.com
- Use url for source
- Use tilde in version
- Clenaup spec file with spec-cleaner
- Update dependencies
- Remove obsolete defines
* Tue Sep 18 2012 idonmez@suse.com
- Add explicit glu dependency
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Aug 29 2011 crrodriguez@opensuse.org
- Fix build with new gnu Ld defaults.
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
- Fixed spec file encoding (fix for RPMLINT warning)
* Mon Apr 26 2010 ro@suse.de
- sanitize version in pkgconfig file
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Tue Oct 14 2008 sbrabec@suse.cz
- Fix for the latest autotools.
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Sat Jul 26 2008 aj@suse.de
- Remove unneccessary and now broken Requires.
* Wed Jul 23 2008 coolo@suse.de
- adding splitprovides to the library package for update
* Mon Jul 21 2008 sbrabec@suse.cz
- Added conflict for FTGLDemo moved from -devel to -demo package.
* Tue Jul 15 2008 sbrabec@suse.cz
- Updated to version 2.1.3-rc5:
  * Stable API. Public headers are now frozen.
  * Fixed several memory corruption and crash bugs
  * Fixed several memory leaks
  * Kerning and glyph performance enhancements
  * The library now also exports a pure C interface
  * Inset/outset contour support for fonts
  * Fix the FTLayout rendering
  * Added new FTLayout and FTSimpleLayout support for layout
    managers
  * Fixed the paths in the XCode project
  * Changed the behaviour of some objects so that if there is an
    error their state isn't changed
  * New, fast FTBufferFont texture fonts
  * UTF-8 support
* Thu Sep 13 2007 sbrabec@suse.cz
- Fixed pkg-config file to include correct freetype (#283824).
* Mon Jan 22 2007 ssommer@suse.de
- fixed same variable used twice build error
* Wed Sep 13 2006 sbrabec@suse.cz
- Split devel subpackage.
* Fri Sep  8 2006 sbrabec@suse.cz
- Build shared library (#197446).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Mon Nov  7 2005 ro@suse.de
- remove extra qualification to fix build with gcc-4.1
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 2.1.2.
* Thu Sep  2 2004 sbrabec@suse.cz
- New SuSE package, version 2.0.11.
